
# Slot: tag


a tag associated with an extension

URI: [linkml:extension_tag](https://w3id.org/linkml/extension_tag)


## Domain and Range

[Extension](Extension.md) &#8594;  <sub>1..1</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents


## Children


## Used by

 * [Annotation](Annotation.md)
 * [Extension](Extension.md)
